<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2009 Georg Ringer (just2b) <http://www.cyberhouse.at>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/
 
/**
 * Userfunction 'user_canonical_check' for the 'canonical' extension.
 *
 * @author	Georg Ringer (just2b) <http://www.cyberhouse.at>
 * @package	TYPO3
 */ 
class user_canonical_check {

	/**
	 * Check for duplicate content in cases of MountPoints
	 * and the page settings "Show content of this page"	 
	 *
	 * @param	string		$content: The PlugIn content
	 * @param	array		$conf: The PlugIn configuration
	 * @return	The content that is displayed on the website
	 */
	function checkDuplicateContent($content, $conf) {
		// default settings
		$link	= '';

		// Check for Mountpoints
		if ($conf['checkMP']==1) {
			$link = $this->checkMountPoints();
		}
				
		// Check for "Show content of this page"		 
		if ($link == '' && $conf['checkContentOfPage']==1) {
			$link = $this->checkContentOfThisPage();
		}
	 
		// Check tt_news for backPid
		if ($link == '' && $conf['checkTTnews']==1) {
			$link = $this->checkNewsBackPid();
		}
		
		// create the canonical tag
		if ($link != '') {
			$tag = $this->cObj->stdWrap($link, $conf['link.']);#'<link rel="canonical" href="'.$link.'" />';
			
			if ($conf['debug']==1) {
				echo htmlspecialchars($tag);
			}
			
			return $tag;
		} else {
			return $link;
		}
	}


	/**
	 * Check for used MountPoints
	 *
	 * @return	Link to the original page
	 */		
	function checkMountPoints() {
		$link = '';
		$vars = t3lib_div::_GET('MP');
		$mpdisable = $GLOBALS['TSFE']->config['config']['MP_disableTypolinkClosestMPvalue']; // default value
		
		// if there is a mountpoint get vars
		if ($vars != '') {		
			// build the link
			$linkConf = array();
			$linkConf['returnLast'] = 'url';
			$linkConf['parameter'] = $GLOBALS['TSFE']->id;
			$linkConf['addQueryString'] = 1;
			$linkConf['addQueryString.']['exclude'] = 'id,MP';

			// disable the mountpoint rendering
			$GLOBALS['TSFE']->config['config']['MP_disableTypolinkClosestMPvalue'] = 1;
			
			// generate the link
			$link = $this->cObj->typolink('', $linkConf);
			
			// enable mountpoint rendering
			$GLOBALS['TSFE']->config['config']['MP_disableTypolinkClosestMPvalue'] = $mpdisable;
		}
		
		return $link;
	}
	

	/**
	 * Check for "Show content of this page"
	 *
	 * @return	Link to the original page
	 */		
	function checkContentOfThisPage() {
		$link = '';
		
		// get the field which holds the page id with the content to show
		$id = $this->cObj->data['content_from_pid'];
	
		// generate the link
		if ($id > 0) {
			$linkConf = array();
			$linkConf['returnLast'] = 'url';
			$linkConf['parameter'] = $id;
			$linkConf['returnLast'] = 'url';
	
			$link = $this->cObj->typolink('', $linkConf);	
		}
		return $link;
	}


	/**
	 * Check for tt_news backPid and create a link to the record without backpid
	 * Important: Doesn't help with indexed_search or bigger cache tables!
	 *
	 * @return	Link to the original page
	 */		 
	function checkNewsBackPid() {
		$link = '';
		
		// news params
		$vars = t3lib_div::_GET('tx_ttnews');
		
		// if this is a news single record with a backpid set
		if (intval($vars['tt_news']) > 0 && intval($vars['backPid']) > 0 ) {
			$found = true;
			
			// build the link without backpid
			$linkConf = array();
			$linkConf['returnLast'] = 'url';
			$linkConf['parameter'] = $GLOBALS['TSFE']->id;
			$linkConf['addQueryString'] = 1;
			$linkConf['addQueryString.']['exclude'] = 'id,tx_ttnews[backPid]';

			$link = $this->cObj->typolink('', $linkConf);
		}
		
		return $link;
	}

}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/canonical/class.user_canonical_check.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/canonical/class.user_canonical_check.php']);
}

?>
